/*
	NOTES:
	
	the pythagoras'd player speed value (called "speed" in the code below) caps
	at 16.666667 or 21 when doing SR50 no matter the Player.ForwardMove or
	Player.SideMove value.
*/

class StepEventHandler : EventHandler
{

	int SprintCounterDrain;
	int SprintCounterRegen;
	
	// can probably be done without a magic number but it works for now
	const MAX_SPEED = 16.666667;
	
	// a wait timer for each player. when wait[i] hits 0 it plays a footstep
	private Array<double> wait;
	
	/*
	*	functions
	*/
	
	private String getStepSound(PlayerPawn pl)
	{
		String flat = TexMan.getName(pl.floorPic);
		Sound test = StringTable.localize("$_STEP_" .. flat).indexOf("_STEP_");
		
		if (test == "{ no sound }") {
			return "step/crete";
		}
		
		return StringTable.localize("$_STEP_" .. flat);
	}
	
	/*
	*	overrides
	*/
	
	override void worldLoaded(WorldEvent e)
	{
		for (int i = 0; i < players.size(); ++i) {			
			wait.insert(i, 1.0);
			Console.printf("%d", consolePlayer);
		}
		
		super.worldLoaded(e);
	}
	
	Override void WorldThingSpawned(WorldEvent e)
	{
		If(e.Thing is "PlayerPawn"&&!e.Thing.FindInventory("SprintCounter"))
		{
			e.Thing.GiveInventory("SprintCounter",128);
		}
	}
	
	override void worldTick()
	{
		double speed;
		PlayerPawn pl;
		SprintCounterDrain = xd3_staminadrain;
		SprintCounterRegen = xd3_staminaregen;
		
		for (int i = 0; i < players.size(); ++i)
		{
			if (players[i].mo)
			{
				pl = players[i].mo;
				
				if (players[i].onground)
				{
					speed = clamp(sqrt(pl.vel.x * pl.vel.x + pl.vel.y * pl.vel.y),
								0.0, MAX_SPEED);
					
					// you can probably find out that this means that a sound is
					// only played when the player is moving > 2.0 speed
					if (speed > 2.0)
					{
						if (wait[i] <= 0.0)
						{
							pl.A_StartSound(getStepSound(pl), CHAN_BODY,
									clamp(speed / MAX_SPEED, 0.4, 1.0));
							wait[i] = 7.0 * clamp(MAX_SPEED / speed, 1.0, 1.5);
							
							//Sprinting add-on by Xim (1/2)
							if (xd3_sprinting == 1)//checks cvar
							{
								if (speed > 8.0)//checks for player speed, 8.0 as a magic number seems to work for now
								{
									//pl.A_TakeInventory("SprintCounter",1);//drains stamina
									if(pl.health < 25)
									{
										pl.A_TakeInventory("SprintCounter",2+SprintCounterDrain);
									}
									else
									{
										pl.A_TakeInventory("SprintCounter",1+SprintCounterDrain);
									}
									if (pl.CountInv("SprintCounter") == 0)//checks for empty stamina
									{
										pl.A_GiveInventory("SprintExhausted",1);//slows down player with fake powerup
										pl.A_StartSound("Player/heartbeat", CHAN_7);
									}
									if (pl.CountInv("IsSprinting") > 1)
									{
										pl.A_GiveInventory("IsSprinting",1);
									}
								}
							}
							//End sprint (1/2)
						}
						
						--wait[i];
					}
					else
					{
						wait[i] = 1.0;
						
						//Sprinting add-on by Xim (2/2)
						if (xd3_sprinting == 1)//checks cvar
						{
							if (level.time % 5 == 0)//regenerates stamina while standing
							{
								if (pl.CountInv("SprintCounter") < 128)
								{
									if(pl.health < 25)
									{
										pl.A_GiveInventory("SprintCounter",2+SprintCounterRegen);
									}
									else
									{
										pl.A_GiveInventory("SprintCounter",1+SprintCounterDrain);
									}
								}
								if (pl.CountInv("IsSprinting") < 1)
								{
										pl.A_TakeInventory("IsSprinting",1);
								}
							}
							if (pl.CountInv("SprintCounter") > 6)//removes slow down after stamina regenerates a bit
							{
								pl.A_TakeInventory("SprintExhausted",1);
							}
						}
						//End sprint (2/2)
					}
				}
				else // to create the "shuffling down stairs" effect
				{
					wait[i] = 0.0;
				}
			}
		}
		super.worldTick();
	}
	
	override void playerEntered(PlayerEvent e)
	{
		wait.insert(e.playerNumber, 1.0);
	}
	
	override void playerRespawned(PlayerEvent e)
	{
		wait[e.playerNumber] = 1.0;
	}
	
	override void playerDisconnected(PlayerEvent e)
	{
	}
	
}

//Sprinting classes
class IsSprinting : Inventory
{
	Default
	{
		+Inventory.IgnoreSkill;
		Inventory.MaxAmount 1;
	}
}

class SprintCounter : Inventory
{
	Default
	{
		+Inventory.IgnoreSkill;
		Inventory.MaxAmount 128;	
	}
}

class SprintExhausted : PowerSpeed
{
	Default
	{
		Powerup.Duration -45;
		Speed 0.5;
	}
}